args <- commandArgs(TRUE)

library(effsize)
library(orddom)

path <- args[1];
optType <- args[2]
output <- args[3]

#Create paths
original <- paste(path,"original/cpuOutput.csv", sep="");
opt <- paste(path,optType,"/cpuOutput.csv", sep="");
all <- paste(path,"All/cpuOutput.csv", sep="");
prog <- paste(path,"Prog/cpuOutput.csv", sep="");


#Load and filter data
data_original<-read.table(original,sep=",",header=TRUE);
data_original <- data_original[which(data_original["TOTAL"] > 0),]
data_opt<-read.table(opt,sep=",",header=TRUE);
data_opt <- data_opt[which(data_opt["TOTAL"] > 0),]
data_all<-read.table(all,sep=",",header=TRUE);
data_all <- data_all[which(data_all["TOTAL"] > 0),]
data_prog <-read.table(prog,sep=",",header=TRUE);
data_prog <- data_prog[which(data_prog["TOTAL"] > 0),]



prec_data = list()
prec_data[[1]] = data_original$TOTAL;
prec_data[[2]] = data_opt$TOTAL;
prec_data[[3]] = data_all$TOTAL;
prec_data[[4]] = data_prog$TOTAL;
types = c("Original",optType,"All","Prog")



#Kruskal Test
g = factor(rep(1:4,c(nrow(data_original), nrow(data_opt), nrow(data_all), nrow(data_prog)   )))
kruskal_pr= kruskal.test(c(data_original$TOTAL, data_opt$TOTAL, data_all$TOTAL, data_prog$TOTAL),g)


# This is the number of pairwise comparisons if kruskal is significant. So, if there are
# 4 samples, there are 3+2+1=6 pairwise comparisons
comparisons = 6

conn <- file(output, "w")
write("Attribute1;Attribute2;p-value_kruskall;k-statistic ;p-value-post-hoc;w-statistic;cliff_delta",conn)


for(i in 1:4){
  for(j in i:4){
    if(i != j){ 
      
      w = wilcox.test(prec_data[[i]],prec_data[[j]], paired =FALSE);
      cohen = cohen.d(as.numeric(prec_data[[i]]),prec_data[[j]]);
      cliff = cohd2delta(cohen$estimate);
      
      
      
      if(kruskal_pr$p.value < 0.05){ 
        #Bonferroni correction
        if (!is.nan(w$p.value) &&  w$p.value < (0.05 / comparisons)){
          write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,w$p.value,w$statistic,cliff,'Reject',sep=";"),conn);
        }
        else{
          write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,w$p.value,w$statistic,cliff,'Accept',sep=";"),conn);
        }
        
      }else{
        write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,'--','--','--','Accept',sep=";"),conn);
      }
      
    }
  } 
}

close(conn)
