args <- commandArgs(TRUE)

library(effsize)
library(orddom)

path <- args[1];
optType <- args[2]
output <- args[3]

#Create paths
original <- paste(path,"original/memoryOutput.csv", sep="");
opt <- paste(path,optType,"/memoryOutput.csv", sep="");
all <- paste(path,"All/memoryOutput.csv", sep="");
prog <- paste(path,"Prog/memoryOutput.csv", sep="");


#Load and filter data
data_original<-read.table(original,sep=",",header=TRUE);
data_opt<-read.table(opt,sep=",",header=TRUE);
data_all<-read.table(all,sep=",",header=TRUE);
data_prog <-read.table(prog,sep=",",header=TRUE);

types = c("Original",optType,"All","Prog")


prec_data = list()
prec_data[[1]] = data_original$avgUss;
prec_data[[2]] = data_opt$avgUss;
prec_data[[3]] = data_all$avgUss;
prec_data[[4]] = data_prog$avgUss;





# ********************** MIN PSS  **********************
conn <- file(paste(output, "_minPss.csv",sep=""), "w")
write("Attribute1;Attribute2;p-value_kruskall;k-statistic ;p-value-post-hoc;w-statistic;cliff_delta",conn)

prec_data = list()
prec_data[[1]] = data_original$minPss;
prec_data[[2]] = data_opt$minPss;
prec_data[[3]] = data_all$minPss;
prec_data[[4]] = data_prog$minPss;

#Kruskal Test
g = factor(rep(1:4,c(nrow(data_original), nrow(data_opt), nrow(data_all), nrow(data_prog)   )))
kruskal_pr= kruskal.test(c(data_original$minPss, data_opt$minPss, data_all$minPss, data_prog$minPss),g)


# This is the number of pairwise comparisons if kruskal is significant. So, if there are
# 4 samples, there are 3+2+1=6 pairwise comparisons
comparisons = 6




for(i in 1:4){
  for(j in i:4){
    if(i != j){ 
      
      w = wilcox.test(prec_data[[i]],prec_data[[j]], paired =FALSE);
      cohen = cohen.d(as.numeric(prec_data[[i]]),prec_data[[j]]);
      cliff = cohd2delta(cohen$estimate);
      
      
      
      if(kruskal_pr$p.value < 0.05){ 
        #Bonferroni correction
        if (!is.nan(w$p.value) &&  w$p.value < (0.05 / comparisons)){
          write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,w$p.value,w$statistic,cliff,'Reject',sep=";"),conn);
        }
        else{
          write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,w$p.value,w$statistic,cliff,'Accept',sep=";"),conn);
        }
        
      }else{
        write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,'--','--','--','Accept',sep=";"),conn);
      }
      
    }
  } 
}





close(conn)
# ********************** AVG PSS  **********************
conn <- file(paste(output, "_avgPss.csv",sep=""), "w")
write("Attribute1;Attribute2;p-value_kruskall;k-statistic ;p-value-post-hoc;w-statistic;cliff_delta",conn)



prec_data = list()
prec_data[[1]] = data_original$avgPss;
prec_data[[2]] = data_opt$avgPss;
prec_data[[3]] = data_all$avgPss;
prec_data[[4]] = data_prog$avgPss;

#Kruskal Test
g = factor(rep(1:4,c(nrow(data_original), nrow(data_opt), nrow(data_all), nrow(data_prog)   )))
kruskal_pr= kruskal.test(c(data_original$avgPss, data_opt$avgPss, data_all$avgPss, data_prog$avgPss),g)


# This is the number of pairwise comparisons if kruskal is significant. So, if there are
# 4 samples, there are 3+2+1=6 pairwise comparisons
comparisons = 6




for(i in 1:4){
  for(j in i:4){
    if(i != j){ 
      
      w = wilcox.test(prec_data[[i]],prec_data[[j]], paired =FALSE);
      cohen = cohen.d(as.numeric(prec_data[[i]]),prec_data[[j]]);
      cliff = cohd2delta(cohen$estimate);
      
      
      
      if(kruskal_pr$p.value < 0.05){ 
        #Bonferroni correction
        if (!is.nan(w$p.value) &&  w$p.value < (0.05 / comparisons)){
          write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,w$p.value,w$statistic,cliff,'Reject',sep=";"),conn);
        }
        else{
          write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,w$p.value,w$statistic,cliff,'Accept',sep=";"),conn);
        }
        
      }else{
        write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,'--','--','--','Accept',sep=";"),conn);
      }
      
    }
  } 
}







close(conn)
# ********************** MAX PSS  **********************
conn <- file(paste(output, "_maxPss.csv",sep=""), "w")
write("Attribute1;Attribute2;p-value_kruskall;k-statistic ;p-value-post-hoc;w-statistic;cliff_delta",conn)


prec_data = list()
prec_data[[1]] = data_original$maxPss;
prec_data[[2]] = data_opt$maxPss;
prec_data[[3]] = data_all$maxPss;
prec_data[[4]] = data_prog$maxPss;

#Kruskal Test
g = factor(rep(1:4,c(nrow(data_original), nrow(data_opt), nrow(data_all), nrow(data_prog)   )))
kruskal_pr= kruskal.test(c(data_original$maxPss, data_opt$maxPss, data_all$maxPss, data_prog$maxPss),g)


# This is the number of pairwise comparisons if kruskal is significant. So, if there are
# 4 samples, there are 3+2+1=6 pairwise comparisons
comparisons = 6




for(i in 1:4){
  for(j in i:4){
    if(i != j){ 
      
      w = wilcox.test(prec_data[[i]],prec_data[[j]], paired =FALSE);
      cohen = cohen.d(as.numeric(prec_data[[i]]),prec_data[[j]]);
      cliff = cohd2delta(cohen$estimate);
      
      
      
      if(kruskal_pr$p.value < 0.05){ 
        #Bonferroni correction
        if (!is.nan(w$p.value) &&  w$p.value < (0.05 / comparisons)){
          write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,w$p.value,w$statistic,cliff,'Reject',sep=";"),conn);
        }
        else{
          write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,w$p.value,w$statistic,cliff,'Accept',sep=";"),conn);
        }
        
      }else{
        write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,'--','--','--','Accept',sep=";"),conn);
      }
      
    }
  } 
}








close(conn)
# ********************** MIN USS  **********************
conn <- file(paste(output, "_minUss.csv",sep=""), "w")
write("Attribute1;Attribute2;p-value_kruskall;k-statistic ;p-value-post-hoc;w-statistic;cliff_delta",conn)



prec_data = list()
prec_data[[1]] = data_original$minUss;
prec_data[[2]] = data_opt$minUss;
prec_data[[3]] = data_all$minUss;
prec_data[[4]] = data_prog$minUss;

#Kruskal Test
g = factor(rep(1:4,c(nrow(data_original), nrow(data_opt), nrow(data_all), nrow(data_prog)   )))
kruskal_pr= kruskal.test(c(data_original$minUss, data_opt$minUss, data_all$minUss, data_prog$minUss),g)


# This is the number of pairwise comparisons if kruskal is significant. So, if there are
# 4 samples, there are 3+2+1=6 pairwise comparisons
comparisons = 6




for(i in 1:4){
  for(j in i:4){
    if(i != j){ 
      
      w = wilcox.test(prec_data[[i]],prec_data[[j]], paired =FALSE);
      cohen = cohen.d(as.numeric(prec_data[[i]]),prec_data[[j]]);
      cliff = cohd2delta(cohen$estimate);
      
      
      
      if(kruskal_pr$p.value < 0.05){ 
        #Bonferroni correction
        if (!is.nan(w$p.value) &&  w$p.value < (0.05 / comparisons)){
          write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,w$p.value,w$statistic,cliff,'Reject',sep=";"),conn);
        }
        else{
          write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,w$p.value,w$statistic,cliff,'Accept',sep=";"),conn);
        }
        
      }else{
        write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,'--','--','--','Accept',sep=";"),conn);
      }
      
    }
  } 
}



close(conn)
# ********************** AVG USS  **********************
conn <- file(paste(output, "_avgUss.csv",sep=""), "w")
write("Attribute1;Attribute2;p-value_kruskall;k-statistic ;p-value-post-hoc;w-statistic;cliff_delta",conn)


prec_data = list()
prec_data[[1]] = data_original$avgUss;
prec_data[[2]] = data_opt$avgUss;
prec_data[[3]] = data_all$avgUss;
prec_data[[4]] = data_prog$avgUss;

#Kruskal Test
g = factor(rep(1:4,c(nrow(data_original), nrow(data_opt), nrow(data_all), nrow(data_prog)   )))
kruskal_pr= kruskal.test(c(data_original$avgUss, data_opt$avgUss, data_all$avgUss, data_prog$avgUss),g)


# This is the number of pairwise comparisons if kruskal is significant. So, if there are
# 4 samples, there are 3+2+1=6 pairwise comparisons
comparisons = 6




for(i in 1:4){
  for(j in i:4){
    if(i != j){ 
      
      w = wilcox.test(prec_data[[i]],prec_data[[j]], paired =FALSE);
      cohen = cohen.d(as.numeric(prec_data[[i]]),prec_data[[j]]);
      cliff = cohd2delta(cohen$estimate);
      
      
      
      if(kruskal_pr$p.value < 0.05){ 
        #Bonferroni correction
        if (!is.nan(w$p.value) &&  w$p.value < (0.05 / comparisons)){
          write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,w$p.value,w$statistic,cliff,'Reject',sep=";"),conn);
        }
        else{
          write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,w$p.value,w$statistic,cliff,'Accept',sep=";"),conn);
        }
        
      }else{
        write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,'--','--','--','Accept',sep=";"),conn);
      }
      
    }
  } 
}



close(conn)
# ********************** MAX USS  **********************
conn <- file(paste(output, "_maxUss.csv",sep=""), "w")
write("Attribute1;Attribute2;p-value_kruskall;k-statistic ;p-value-post-hoc;w-statistic;cliff_delta",conn)



prec_data = list()
prec_data[[1]] = data_original$maxUss;
prec_data[[2]] = data_opt$maxUss;
prec_data[[3]] = data_all$maxUss;
prec_data[[4]] = data_prog$maxUss;

#Kruskal Test
g = factor(rep(1:4,c(nrow(data_original), nrow(data_opt), nrow(data_all), nrow(data_prog)   )))
kruskal_pr= kruskal.test(c(data_original$maxUss, data_opt$maxUss, data_all$maxUss, data_prog$maxUss),g)


# This is the number of pairwise comparisons if kruskal is significant. So, if there are
# 4 samples, there are 3+2+1=6 pairwise comparisons
comparisons = 6




for(i in 1:4){
  for(j in i:4){
    if(i != j){ 
      
      w = wilcox.test(prec_data[[i]],prec_data[[j]], paired =FALSE);
      cohen = cohen.d(as.numeric(prec_data[[i]]),prec_data[[j]]);
      cliff = cohd2delta(cohen$estimate);
      
      
      
      if(kruskal_pr$p.value < 0.05){ 
        #Bonferroni correction
        if (!is.nan(w$p.value) &&  w$p.value < (0.05 / comparisons)){
          write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,w$p.value,w$statistic,cliff,'Reject',sep=";"),conn);
        }
        else{
          write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,w$p.value,w$statistic,cliff,'Accept',sep=";"),conn);
        }
        
      }else{
        write(paste(types[i],types[j],kruskal_pr$p.value,kruskal_pr$statistic,'--','--','--','Accept',sep=";"),conn);
      }
      
    }
  } 
}



close(conn)






